[jhalfs] 01/12: Adapt jhalfs to kde6

"Git Owner" ([email protected] via alfs-discuss Mailing List) <[email protected]> Wed, 22 Jan 2025 11:27:16 +0000
Newsgroups gmane.linux.lfs.automated
Message-ID <[email protected]>
This is an automated email from the git hooks/post-receive script.

git pushed a commit to branch trunk
in repository jhalfs.

commit 3489522a9516698264398757fe87d1639b2ec498
Author: Pierre Labastie <[email protected]>
AuthorDate: Fri Jan 10 19:25:52 2025 +0100

    Adapt jhalfs to kde6
    
    Also adapt to changes in plasma post-install
    Presently, it only works with new book layout where one package is
    at only one place... branch plabs/no-build-twice
---
 BLFS/gen-special.sh       | 19 ++++++++++---------
 BLFS/xsl/gen_config.xsl   |  2 +-
 BLFS/xsl/gen_pkg_list.xsl |  4 ++--
 BLFS/xsl/make_book.xsl    | 36 +++++++++++++++++++-----------------
 4 files changed, 32 insertions(+), 29 deletions(-)

diff --git a/BLFS/xsl/gen_config.xsl b/BLFS/xsl/gen_config.xsl
index 00082bd..59a0f16 100644
--- a/BLFS/xsl/gen_config.xsl
+++ b/BLFS/xsl/gen_config.xsl
@@ -312,7 +312,7 @@ if&#9;MENU_</xsl:text>
       <!-- for compound packages, default to selecting all the subpackages-->
         <xsl:when test="contains(../name,'xorg') or
                         contains(../name,'plasma') or
-                        contains(../name,'kf5') or
+                        contains(../name,'kf6') or
                         contains(../name,'xcb-utilities')">
           <xsl:text>y
 
diff --git a/BLFS/xsl/gen_pkg_list.xsl b/BLFS/xsl/gen_pkg_list.xsl
index 3fdee71..4a014ec 100644
--- a/BLFS/xsl/gen_pkg_list.xsl
+++ b/BLFS/xsl/gen_pkg_list.xsl
@@ -360,8 +360,8 @@
         <xsl:when test="@role='nodep'"/>
 <!-- Call list expansion when we have a compound package -->
         <xsl:when test="contains(@linkend,'xorg7-') or
-                        @linkend='kf5-frameworks' or
-                        @linkend='plasma5-build' or
+                        @linkend='kf6-frameworks' or
+                        @linkend='plasma-build' or
                         @linkend='xcb-utilities'">
           <xsl:call-template name="expand-deps">
             <xsl:with-param name="section">
diff --git a/BLFS/xsl/make_book.xsl b/BLFS/xsl/make_book.xsl
index 75c6a42..d13b0a5 100644
--- a/BLFS/xsl/make_book.xsl
+++ b/BLFS/xsl/make_book.xsl
@@ -60,7 +60,7 @@
      sect2 (python/perl modules/dependencies )
      The templates after this one treat each of those cases.
      However, some items are sub-packages of compound packages (xorg7-*,
-     kf5, plasma), and not id.
+     xcb-utils, kf6, plasma), and not id.
      We need special instructions in that case.
      The difficulty is that some of those names *are* id's,
      because they are referenced in the index.
@@ -118,7 +118,7 @@
             </xsl:when>
             <xsl:when test="$list='plasma-post-install'">
               <xsl:apply-templates
-                select="//sect1[@id='plasma5-build']"
+                select="//sect1[@id='plasma-build']"
                 mode="plasma-post-install"/>
             </xsl:when>
             <xsl:when test="not(id($list)[self::sect1 or self::sect2])">
@@ -127,7 +127,7 @@
               <xsl:apply-templates
                 select="//sect1[(contains(@id,'xorg7') or
                                  contains(@id,'frameworks') or
-                                 contains(@id,'plasma5') or
+                                 contains(@id,'plasma-build') or
                                  contains(@id,'xcb-utilities'))
                                  and .//userinput/literal[contains(string(),
                                             concat($list,'-'))]]"
@@ -507,7 +507,8 @@
     </sect2>
   </xsl:template>
 
-<!-- we have got an xorg package. We are at the installation page
+<!-- we have gotten an xorg package (or xcb-utils or plasma or fk6).
+     We are at the installation page
      but now we need to make an autonomous page from the global
      one -->
   <xsl:template match="sect1" mode="compound">
@@ -519,8 +520,8 @@
                         select="string(.//userinput[starts-with(string(),'cat ')])"/>
       </xsl:call-template>
     </xsl:variable>
-    <!-- Unfortunately, there are packages in kf5 and plasma5 that
-         starts in the same way: for example kwallet in kf5
+    <!-- Unfortunately, there are packages in kf6 and plasma that
+         starts in the same way: for example kwallet in kf6
          and kwallet-pam in plasma. So we may arrive here with
          package=kwallet and tarball=kwallet-pam-(version).tar.xz.
          We should not continue in this case. For checking, transform
@@ -576,10 +577,10 @@
                   <!-- $download-dir contains the trailing / for xorg,
                        but not for KDE... -->
                   <xsl:if test="contains(@id,'frameworks') or
-                                contains(@id,'plasma5')">
+                                contains(@id,'plasma')">
                     <xsl:text>/</xsl:text>
                   </xsl:if>
-                  <!-- Some kf5 packages are in a subdirectory -->
+                  <!-- Some kf packages are in a subdirectory
                   <xsl:if test="$package='khtml' or
                                 $package='kdelibs4support' or
                                 $package='kdesignerplugin' or
@@ -590,7 +591,7 @@
                                 $package='kross' or
                                 $package='kxmlrpcclient'">
                     <xsl:text>portingAids/</xsl:text>
-                  </xsl:if>
+                  </xsl:if>-->
                   <xsl:value-of select="$tarball"/>
                 </xsl:attribute>
                </xsl:element>
@@ -626,7 +627,7 @@
           <!-- packagedir is used in xorg lib instructions -->
           <screen><userinput>packagedir=<xsl:value-of
                       select="substring-before($tarball,'.tar.')"/>
-           <!-- name is used in kf5 instructions -->
+           <!-- name is used in kf6 instructions -->
             <xsl:text>
 name=$(echo $packagedir | sed 's/-[[:digit:]].*//')
 </xsl:text>
@@ -727,12 +728,12 @@ name=$(echo $packagedir | sed 's/-[[:digit:]].*//')
 
   <xsl:template name="inst-instr">
     <!-- This template is necessary because of the "libpciaccess" case in Xorg
-         libraries and the "kapidox" case in kf5:
+         libraries and the "kapidox" case in kf6:
          Normally, the general instructions extract the package and change
          to the extracted dir for running the installation instructions.
          When installing a sub-package of a compound package, the installation
          instructions to be run are located between a pushd and a popd,
-         *except* for Xorg libraries and kf5, where a popd occurs inside a
+         *except* for Xorg libraries and kf6, where a popd occurs inside a
          case for libpciaccess and kapidox...
          So we call this template with a "inst-instr" string that contains
          everything after the pushd.-->
@@ -787,9 +788,10 @@ name=$(echo $packagedir | sed 's/-[[:digit:]].*//')
 
         <para>
           Install <application><xsl:value-of select="$package"/></application>
-          by running the following commands:
+          by running the following commands as the
+          <systemitem class="username">root</systemitem> user:
         </para>
-        <screen role="root">
+<!--    <screen role="root">
           <userinput>
             <xsl:call-template name="plasma-sessions">
               <xsl:with-param
@@ -797,12 +799,12 @@ name=$(echo $packagedir | sed 's/-[[:digit:]].*//')
                 select="string(.//userinput[contains(text(),'xsessions')])"/>
             </xsl:call-template>
           </userinput>
-        </screen>
+        </screen>-->
         <xsl:copy-of select=".//screen[@role='root']"/>
       </sect2>
     </xsl:element><!-- sect1 -->
   </xsl:template>
-
+  <!--
   <xsl:template name="plasma-sessions">
     <xsl:param name="p-sessions-text"/>
     <xsl:choose>
@@ -823,6 +825,6 @@ name=$(echo $packagedir | sed 's/-[[:digit:]].*//')
         <xsl:copy-of select="$p-sessions-text"/>
       </xsl:otherwise>
     </xsl:choose>
-  </xsl:template>
+  </xsl:template>-->
 
 </xsl:stylesheet>

diff --git a/BLFS/gen-special.sh b/BLFS/gen-special.sh
index 82f81ea..72e29b4 100755
--- a/BLFS/gen-special.sh
+++ b/BLFS/gen-special.sh
@@ -37,7 +37,7 @@ EXCEPTIONS=$(grep 'ENTITY.*version[ ]*"[^0-9"&.].*[0-9]' ${BLFS_DIR}/packages.en
 
 # Non-versioned packages:
 NV_LIST="postlfs-config-profile postlfs-config-random postlfs-config-vimrc \
-initramfs xorg-env kde-pre-install-config kf5-intro \
+initramfs xorg-env kde-pre-install-config kf6-intro \
 lxqt-pre-install lxqt-post-install ojdk-conf tex-path"
 
 cat >$SPECIAL_FILE << EOF
@@ -59,12 +59,12 @@ EOF
 
 # Non-versionned packages. Add to NV_LIST if you need more.
 for nv_id in $NV_LIST; do
 # Actually, kf5-intro contains some version info, so should be
 # versioned. For other packages, we define version to 1.0.0
 # because the DTD needs a version tag.
   DUM_VER=1.0.0
-  if [ $nv_id = kf5-intro ]; then
-    DUM_VER=$(grep kf5-version $BLFS_DIR/packages.ent | \
+  if [ $nv_id = kf6-intro ]; then
+    DUM_VER=$(grep kf6-version $BLFS_DIR/packages.ent | \
               sed 's/[^"]*"\([^"]*\).*/\1/')
   fi
   cat >>$SPECIAL_FILE << EOF
@@ -96,9 +96,10 @@ EOF
 done
 
 # Taking packages contained in pages installing several packages (x7* except
 # x7driver, kf5-frameworks, and plasma5-all), as versionned modules.
 # We also write a dependency expansion when a dep is of the form
 # xorg7-something or kf5-frameworks or plasma5-build. Since that is another
 # template, we need a temporary file, which we shall concatenate at the end
 cat >tmpfile << EOF
   <xsl:template name="expand-deps">
@@ -108,8 +109,8 @@ cat >tmpfile << EOF
     <xsl:choose>
 EOF
 for file in $(ls ${BLFS_DIR}/x/installing/x7* | grep -v x7driver) \
-	    ${BLFS_DIR}/kde/kf5/kf5-frameworks.xml                \
-            ${BLFS_DIR}/kde/plasma5/plasma-all.xml                \
+	    ${BLFS_DIR}/kde/kf6/kf6-frameworks.xml                \
+            ${BLFS_DIR}/kde/plasma/plasma-all.xml                \
             ${BLFS_DIR}/x/installing/xcb-utilities.xml; do
   id=$(grep xreflabel $file | sed 's@.*id="\([^"]*\).*@\1@')
   cat >>$SPECIAL_FILE << EOF
@@ -59,12 +59,12 @@ EOF
 # Non-versionned packages. Add to NV_LIST if you need more.
 for nv_id in $NV_LIST; do
-# Actually, kf5-intro contains some version info, so should be
+# Actually, kf6-intro contains some version info, so should be
 # versioned. For other packages, we define version to 1.0.0
 # because the DTD needs a version tag.
@@ -96,9 +96,10 @@ EOF
 
 # Taking packages contained in pages installing several packages (x7* except
-# x7driver, kf5-frameworks, and plasma5-all), as versionned modules.
-# We also write a dependency expansion when a dep is of the form
-# xorg7-something or kf5-frameworks or plasma5-build. Since that is another
+# x7driver, xcb-utilities, kf6-frameworks, and plasma-all), as versionned
+# modules. We also write a dependency expansion when a dep is of the form
+# xorg7-something or xcb-utils or kf6-frameworks or plasma-build.
+# Since that is another
 # template, we need a temporary file, which we shall concatenate at the end
 cat >tmpfile << EOF
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.

-- 
http://lists.linuxfromscratch.org/sympa/info/alfs-discuss
Unsubscribe: See the above information page